==> rcsb.app.file-0.13.tar.gz: rcsb.app.file-0.13/rcsb/app/file/JWTAuthBearer.py <==
##
# File: JWTAuthBearer.py
# Date: 23-Aug-2021
#
##
import logging
import os

from fastapi import HTTPException
from fastapi import Request
from fastapi.security import HTTPAuthorizationCredentials
from fastapi.security import HTTPBearer

from rcsb.app.file.JWTAuthToken import JWTAuthToken

os.environ["CACHE_PATH"] = os.environ.get("CACHE_PATH", os.path.join("rcsb", "app", "data"))
os.environ["CONFIG_FILE"] = os.environ.get("CONFIG_FILE", os.path.join("rcsb", "app", "config", "config.yml"))

logger = logging.getLogger(__name__)


class JWTAuthBearer(HTTPBearer):
    def __init__(self, auto_error: bool = True):
        super(JWTAuthBearer, self).__init__(auto_error=auto_error)
        self.__au = JWTAuthToken(os.environ["CACHE_PATH"], os.environ["CONFIG_FILE"])

    async def __call__(self, request: Request):
        credentials: HTTPAuthorizationCredentials = await super(JWTAuthBearer, self).__call__(request)
        if credentials:
            if not credentials.scheme == "Bearer":
                raise HTTPException(status_code=403, detail="Missing Bearer details")
            if not self.validateToken(credentials.credentials):
                raise HTTPException(status_code=403, detail="Invalid or expired token")
            return credentials.credentials
        else:
            raise HTTPException(status_code=403, detail="Invalid authorization ")

    def validateToken(self, token: str) -> bool:
        try:
            payload = self.__au.decodeToken(token)
        except Exception:
            payload = None
        return payload is not None

==> rcsb.app.file-0.23.tar.gz: rcsb.app.file-0.23/rcsb/app/file/JWTAuthBearer.py <==
##
# File: JWTAuthBearer.py
# Date: 23-Aug-2021
#
##
import logging
import os

from fastapi import HTTPException
from fastapi import Request
from fastapi.security import HTTPAuthorizationCredentials
from fastapi.security import HTTPBearer

from rcsb.app.file.JWTAuthToken import JWTAuthToken
from rcsb.app.file.ConfigProvider import ConfigProvider

logger = logging.getLogger(__name__)


class JWTAuthBearer(HTTPBearer):
    def __init__(self, auto_error: bool = True):
        super(JWTAuthBearer, self).__init__(auto_error=auto_error)
        self.__au = JWTAuthToken(os.environ["CONFIG_FILE"])

    async def __call__(self, request: Request):
        credentials: HTTPAuthorizationCredentials = await super(JWTAuthBearer, self).__call__(request)
        if credentials:
            if not credentials.scheme == "Bearer":
                raise HTTPException(status_code=403, detail="Missing Bearer details")
            if not self.validateToken(credentials.credentials):
                raise HTTPException(status_code=403, detail="Invalid or expired token")
            return credentials.credentials
        else:
            raise HTTPException(status_code=403, detail="Invalid authorization ")

    def validateToken(self, token: str) -> bool:
        configFilePath = os.environ.get("CONFIG_FILE")
        cP = ConfigProvider(configFilePath)
        if token == cP.get("JWT_DISABLE"):
            return True
        try:
            payload = self.__au.decodeToken(token)
        except Exception:
            payload = None
        return payload is not None
